sigma_zf: Empirical cross-covarinace.
Description
Function that calculates the empirical cross-covariance of order h for a bivariate time series.
Usage
sigma_zf(h, vec1, vec2, N)
Arguments
vec1
observations for the first variable of the bivariate time series.
vec2
observations for the second variable of the bivariate time series.
N
the common length of vec1 and vec2.
Value
The value of lambda that corresponds to a smoothing level s.